summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMike Fulbright <msf@redhat.com>2001-01-23 21:35:07 +0000
committerMike Fulbright <msf@redhat.com>2001-01-23 21:35:07 +0000
commit9391b848bea6b9072b3343dbefc63a2515442201 (patch)
tree260a56e7d380cb27c6d23e2dc9b15b0d954a79ee
parentefd917a7fb2596f375d9aea78599bb8b89dfeb11 (diff)
downloadanaconda-9391b848bea6b9072b3343dbefc63a2515442201.tar.gz
anaconda-9391b848bea6b9072b3343dbefc63a2515442201.tar.xz
anaconda-9391b848bea6b9072b3343dbefc63a2515442201.zip
make lba32 warning a dialog under GUI install, and fix off by one bug with endpoint (should be 1024, not 1023)
-rw-r--r--iw/installpath_gui.py2
-rw-r--r--iw/rootpartition_gui.py56
-rw-r--r--lilo.py2
-rw-r--r--textw/partitioning_text.py8
4 files changed, 58 insertions, 10 deletions
diff --git a/iw/installpath_gui.py b/iw/installpath_gui.py
index f56ed4fa3..c4d651250 100644
--- a/iw/installpath_gui.py
+++ b/iw/installpath_gui.py
@@ -54,7 +54,7 @@ class InstallPathWindow (InstallWindow):
( AutoPartitionWindow, "partition" ),
FDiskWindow,
( PartitionWindow, "partition" ),
- ( LBA32WarningWindow, "lba32warning"),
+# ( LBA32WarningWindow, "lba32warning"),
( FormatWindow, "format" ),
( BootloaderWindow, BootloaderSkipname ),
( NetworkWindow, "network" ),
diff --git a/lilo.py b/lilo.py
index 0813b6bfa..fc497e178 100644
--- a/lilo.py
+++ b/lilo.py
@@ -290,7 +290,7 @@ class LiloConfiguration:
if self.edd:
from log import log
maxcyl = fstab.getBootPartitionMaxCylFromDrive()
- if maxcyl > 1023:
+ if maxcyl > 1024:
log("Maximum cylinder is %s, using lba32" % maxcyl)
useLBA32 = 1
diff --git a/iw/rootpartition_gui.py b/iw/rootpartition_gui.py
index 7a3a8aec2..6d2496f4b 100644
--- a/iw/rootpartition_gui.py
+++ b/iw/rootpartition_gui.py
@@ -67,6 +67,48 @@ class PartitionWindow (InstallWindow):
return 1
+
+ def lba32Check (self):
+ # check if boot partition is above 1024 cyl limit
+ if iutil.getArch() != "i386":
+ return 0
+
+ maxcyl = self.todo.fstab.getBootPartitionMaxCylFromDesired()
+ log("Maximum cylinder is %s" % maxcyl)
+
+ if maxcyl > 1024:
+ if not self.todo.fstab.edd:
+ rc = self.todo.intf.messageWindow(_("Warning"),
+ _("You have put the partition containing the kernel (the "
+ "boot partition) above the 1024 cylinder limit, and "
+ "it appears that this systems BIOS does not support "
+ "booting from above this limit. Proceeding will "
+ "most likely make the system unable to reboot into "
+ "Linux.\n\n"
+ "If you choose to proceed, it is HIGHLY recommended "
+ "you make a boot floppy when asked. This will "
+ "guarantee you have a way to boot into the system "
+ "after installation.\n\n"
+ "Press OK to proceed, or Cancel to go back and "
+ "reassign the boot partition."),
+ type = "okcancel").getrc()
+ return rc
+ else:
+ self.todo.intf.messageWindow(_("Warning"),
+ _("You have put the partition containing the kernel (the "
+ "boot partition) above the 1024 cylinder limit. "
+ "It appears that this systems BIOS supports "
+ "booting from above this limit. \n\n"
+ "It is HIGHLY recommended you make a boot floppy when "
+ "asked by the installer, as this is a new feature in "
+ "recent motherboards and is not always reliable. "
+ "Making a boot disk will guarantee you can boot "
+ "your system once installed."),
+ type = "ok")
+ return 0
+
+ return 0
+
def getNext (self):
if not self.running: return 0
self.todo.fstab.runDruidFinished()
@@ -84,6 +126,12 @@ class PartitionWindow (InstallWindow):
bootPartition = None
rootPartition = None
+ threads_leave()
+ rc = self.lba32Check ()
+ threads_enter()
+ if rc:
+ raise gui.StayOnScreen
+
if not self.checkSwap ():
return PartitionWindow
@@ -388,20 +436,20 @@ class LBA32WarningWindow(InstallWindow):
def getScreen (self):
# check if boot partition is above 1023 cyl limit
if iutil.getArch() != "i386":
return None
maxcyl = self.todo.fstab.getBootPartitionMaxCylFromDesired()
log("Maximum cylinder is %s" % maxcyl)
- if maxcyl > 1023:
+ if maxcyl > 1024:
vbox = GtkVBox (FALSE, 5)
if not self.todo.fstab.edd:
label = GtkLabel (
_("You have put the partition containing the kernel (the "
- "boot partition) above the 1023 cylinder limit, and "
+ "boot partition) above the 1024 cylinder limit, and "
"it appears that this systems BIOS does not support "
"booting from above this limit. Proceeding will "
"most likely make the system unable to reboot into "
@@ -414,7 +462,7 @@ class LBA32WarningWindow(InstallWindow):
else:
label = GtkLabel (
_("You have put the partition containing the kernel (the "
- "boot partition) above the 1023 cylinder limit. "
+ "boot partition) above the 1024 cylinder limit. "
"It appears that this systems BIOS supports "
"booting from above this limit. \n\n"
"It is HIGHLY recommended you make a boot floppy when "
@@ -388,20 +436,20 @@ class LBA32WarningWindow(InstallWindow):
def getScreen (self):
- # check if boot partition is above 1023 cyl limit
+ # check if boot partition is above 1024 cyl limit
if iutil.getArch() != "i386":
return None
diff --git a/textw/partitioning_text.py b/textw/partitioning_text.py
index 92ba573e4..56e85aef5 100644
--- a/textw/partitioning_text.py
+++ b/textw/partitioning_text.py
@@ -357,17 +357,17 @@ class LBA32WarningWindow:
if dir == -1:
return INSTALL_NOOP
# check if boot partition is above 1023 cyl limit
if iutil.getArch() != "i386":
return INSTALL_NOOP
maxcyl = todo.fstab.getBootPartitionMaxCylFromDesired()
log("Maximum cylinder is %s" % maxcyl)
- if maxcyl > 1023:
+ if maxcyl > 1024:
if not todo.fstab.edd:
rc = ButtonChoiceWindow(screen, _("Boot Partition Warning"),
_("You have put the partition containing the kernel (the "
- "boot partition) above the 1023 cylinder limit, and "
+ "boot partition) above the 1024 cylinder limit, and "
"it appears that this systems BIOS does not support "
"booting from above this limit. Proceeding will "
"most likely make the system unable to reboot into "
@@ -387,7 +387,7 @@ class LBA32WarningWindow:
else:
rc = ButtonChoiceWindow(screen, _("Boot Partition Warning"),
_("You have put the partition containing the kernel (the "
- "boot partition) above the 1023 cylinder limit. "
+ "boot partition) above the 1024 cylinder limit. "
"It appears that this systems BIOS supports "
"booting from above this limit. \n\n"
"It is HIGHLY recommended you make a boot floppy when "
@@ -357,17 +357,17 @@ class LBA32WarningWindow:
if dir == -1:
return INSTALL_NOOP
- # check if boot partition is above 1023 cyl limit
+ # check if boot partition is above 1024 cyl limit
if iutil.getArch() != "i386":
return INSTALL_NOOP